@@ -1,6 +1,6 @@
 ;;; base.scm -- The base markup package of Skribe/Skribilo.
 ;;;
-;;; Copyright 2005, 2006, 2007  Ludovic Courts  <ludo@gnu.org>
+;;; Copyright 2005, 2006, 2007, 2008  Ludovic Courts  <ludo@gnu.org>
 ;;; Copyright 2003, 2004  Manuel Serrano
 ;;;
 ;;;
@@ -30,7 +30,7 @@
   :autoload   (srfi srfi-1)        (every any filter)
   :autoload   (skribilo evaluator) (include-document)
   :autoload   (skribilo engine)    (engine?)
-  :autoload   (skribilo parameters)(*document-path*)
+  :autoload   (skribilo parameters)(*document-path* *sui-path*)
 
   ;; optional ``sub-packages''
   :autoload   (skribilo biblio)    (*bib-table* resolve-bib
@@ -697,7 +697,8 @@
 		      (ident #f) (class #f) (&location #f)
 		      (border #f) (width #f)
 		      (frame 'none) (rules 'none)
-		      (cellstyle 'collapse) (cellpadding #f) (cellspacing #f))
+		      (cellstyle 'collapse) (cellpadding #f) (cellspacing #f)
+                      (rulecolor #f))
    (let ((frame (cond
 		   ((string? frame)
 		    (string->symbol frame))
@@ -740,6 +741,9 @@
 	     (options `((:frame ,frame)
 			(:rules ,rules)
 			(:cellstyle ,cellstyle)
+                        ,@(if rulecolor
+                              `((:rulecolor ,rulecolor))
+                              '())
 			,@(the-options opts :ident :class)))
 	     (body (parse-list-of 'table 'tr (the-body opts))))))))
 
@@ -1083,15 +1087,13 @@
 		   (options `((kind ,kind) ,@(the-options opts :ident :class)))
 		   (body text))))))
    (define (skribe-ref skribe)
-      (let ((path (search-path (*document-path*) skribe)))
-	 (if (not path)
-	     (unref #f skribe 'sui-file)
-	     (let* ((sui (load-sui path))
-		    (os (the-options opts :skribe :class :text))
-		    (u (sui-ref->url (dirname path) sui ident os)))
-		(if (not u)
-		    (unref #f os 'sui-ref)
-		    (ref :url u :text text :ident ident :class class))))))
+     (let* ((sui (load-sui skribe))
+            (os  (the-options opts :skribe :class :text))
+            (u   (sui-ref->url (dirname (search-path (*sui-path*) skribe))
+                               sui ident os)))
+       (if (not u)
+           (unref #f os 'sui-ref)
+           (ref :url u :text text :class class))))
    (define (handle-ref text)
       (new markup
 	 (markup 'ref)
