@@ -1,6 +1,6 @@
 ;;; eq.scm  --  An equation formatting package.
 ;;;
-;;; Copyright 2005, 2006, 2007  Ludovic Courts <ludovic.courtes@laas.fr>
+;;; Copyright 2005, 2006, 2007, 2008  Ludovic Courts <ludo@gnu.org>
 ;;;
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify
@@ -24,6 +24,7 @@
   :use-module (skribilo writer)
   :use-module (skribilo engine)
   :use-module (skribilo lib)
+  :use-module (skribilo condition)
   :use-module (skribilo utils syntax)
   :use-module (skribilo utils keywords) ;; `the-options', etc.
   :autoload   (skribilo package base) (it symbol sub sup)
@@ -31,6 +32,8 @@
   :autoload   (skribilo resolve)      (resolve-counter)
 
   :use-module (srfi srfi-1)
+  :autoload   (srfi srfi-34)          (raise)
+  :use-module (srfi srfi-35)
   :use-module (srfi srfi-39)
   :use-module (ice-9 optargs))
 
@@ -361,9 +364,10 @@ a symbol representing the mathematical operator denoted by @var{m} (e.g.,
 		     (if (list? first)
 			 (if (null? (cdr body))
 			     (append (reverse! result) first)
-			     (skribe-error 'eq:apply
-					   "wrong argument type"
-					   body))
+                             (raise (condition
+                                     (&invalid-argument-error
+                                      (proc-name 'eq:apply)
+                                      (argument  body)))))
 			 (loop (cdr body) (cons first result)))))))))
 
 
@@ -419,11 +423,11 @@ a symbol representing the mathematical operator denoted by @var{m} (e.g.,
 	       (cond ((not renderer) ;; default: use the current engine
 		      (output (it (markup-body node)) engine))
 		     ((symbol? renderer)
-                      (parameterize ((*embedded-renderer* #t))
-                        (case renderer
-                          ;; FIXME: We should have an `embed' slot for each
-                          ;; engine class similar to `lout-illustration'.
-                          ((lout)
+                      (case renderer
+                        ;; FIXME: We should have an `embed' slot for each
+                        ;; engine class similar to `lout-illustration'.
+                        ((lout)
+                         (parameterize ((*embedded-renderer* #t))
                            (let ((lout-code
                                   (with-output-to-string
                                     (lambda ()
@@ -431,19 +435,24 @@ a symbol representing the mathematical operator denoted by @var{m} (e.g.,
                              (output (lout-illustration
                                       :ident (markup-ident node)
                                       lout-code)
-                                     engine)))
-                          (else
-                           (skribe-error 'eq "invalid renderer" renderer)))))
+                                     engine))))
+                        (else
+                         (raise (condition
+                                 (&invalid-argument-error
+                                  (proc-name 'eq)
+                                  (argument  renderer)))))))
 		     ;; FIXME: `engine?' and `engine-class?'
 		     (else
-		      (skribe-error 'eq "`:renderer' -- wrong argument type"
-				    renderer))))))
+                      (raise (condition
+                              (&invalid-argument-error
+                               (proc-name 'eq)
+                               (argument  renderer)))))))))
 
-(define-macro (simple-markup-writer op . obj)
+(define (simple-markup-writer op . obj)
   ;; Note: The text-only rendering is less ambiguous if we parenthesize
   ;; without taking operator precedence into account.
   (let ((precedence (operator-precedence op)))
-    `(markup-writer ',(symbol-append 'eq: op) (find-engine 'base)
+    (markup-writer (symbol-append 'eq: op) (find-engine 'base)
        :action (lambda (node engine)
 		  (let loop ((operands (markup-body node)))
 		   (if (null? operands)
@@ -455,9 +464,7 @@ a symbol representing the mathematical operator denoted by @var{m} (e.g.,
  				    (>= (operator-precedence
                                          (equation-markup-name->operator
                                           (markup-markup o)))
-                                        ,precedence)
-				    )
-			       ))
+                                        precedence))))
 
 			 (display (if need-paren? "(" ""))
 			 (output o engine)
@@ -465,25 +472,25 @@ a symbol representing the mathematical operator denoted by @var{m} (e.g.,
 			 (if (pair? (cdr operands))
 			     (begin
 			       (display " ")
-			       (output ,(if (null? obj)
-					    (symbol->string op)
-					    (car obj))
+			       (output (if (null? obj)
+                                           (symbol->string op)
+                                           (car obj))
 				       engine)
 			       (display " ")))
 			 (loop (cdr operands)))))))))
 
-(simple-markup-writer +)
-(simple-markup-writer -)
-(simple-markup-writer /)
-(simple-markup-writer * (symbol "times"))
+(simple-markup-writer '+)
+(simple-markup-writer '-)
+(simple-markup-writer '/)
+(simple-markup-writer '* (symbol "times"))
 
-(simple-markup-writer =)
-(simple-markup-writer != (symbol "neq"))
-(simple-markup-writer ~= (symbol "approx"))
-(simple-markup-writer <)
-(simple-markup-writer >)
-(simple-markup-writer >= (symbol "ge"))
-(simple-markup-writer <= (symbol "le"))
+(simple-markup-writer '=)
+(simple-markup-writer '!= (symbol "neq"))
+(simple-markup-writer '~= (symbol "approx"))
+(simple-markup-writer '<)
+(simple-markup-writer '>)
+(simple-markup-writer '>= (symbol "ge"))
+(simple-markup-writer '<= (symbol "le"))
 
 (markup-writer 'eq:sqrt (find-engine 'base)
    :action (lambda (node engine)
@@ -491,8 +498,8 @@ a symbol representing the mathematical operator denoted by @var{m} (e.g.,
 	     (output (markup-body node) engine)
 	     (display ")")))
 
-(define-macro (simple-binary-markup-writer op obj)
-  `(markup-writer ',(symbol-append 'eq: op) (find-engine 'base)
+(define (simple-binary-markup-writer op obj)
+  (markup-writer (symbol-append 'eq: op) (find-engine 'base)
      :action (lambda (node engine)
 	       (let ((body (markup-body node)))
 		 (if (= (length body) 2)
@@ -501,13 +508,14 @@ a symbol representing the mathematical operator denoted by @var{m} (e.g.,
 		       (display (if (equation-markup? first) "(" " "))
 		       (output first engine)
 		       (display (if (equation-markup? first) ")" " "))
-		       (output ,obj engine)
+		       (output obj engine)
 		       (display (if (equation-markup? second) "(" ""))
 		       (output second engine)
 		       (display (if (equation-markup? second) ")" "")))
-		     (skribe-error ',(symbol-append 'eq: op)
-				   "wrong argument type"
-				   body))))))
+		     (raise (condition
+                             (&invalid-argument-error
+                              (proc-name (symbol-append 'eq: op))
+                              (argument  body)))))))))
 
 (markup-writer 'eq:expt (find-engine 'base)
    :action (lambda (node engine)
@@ -520,8 +528,8 @@ a symbol representing the mathematical operator denoted by @var{m} (e.g.,
 		       (display (if (equation-markup? first) ")" ""))
 		       (output (sup second) engine))))))
 
-(simple-binary-markup-writer in    (symbol "in"))
-(simple-binary-markup-writer notin (symbol "notin"))
+(simple-binary-markup-writer 'in    (symbol "in"))
+(simple-binary-markup-writer 'notin (symbol "notin"))
 
 (markup-writer 'eq:apply (find-engine 'base)
    :action (lambda (node engine)
